==> huaweicloudsdkrds-3.1.139-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/list_update_backup_enhance_policy_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListUpdateBackupEnhancePolicyRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'instance_id': 'str',
        'time_zone': 'str'
    }

    attribute_map = {
        'instance_id': 'instance_id',
        'time_zone': 'time_zone'
    }

    def __init__(self, instance_id=None, time_zone=None):
        """ListUpdateBackupEnhancePolicyRequest

        The model defined in huaweicloud sdk

        :param instance_id: 实例ID
        :type instance_id: str
        :param time_zone: 用户当前时区，例：plus08
        :type time_zone: str
        """
        
        

        self._instance_id = None
        self._time_zone = None
        self.discriminator = None

        self.instance_id = instance_id
        if time_zone is not None:
            self.time_zone = time_zone

    @property
    def instance_id(self):
        """Gets the instance_id of this ListUpdateBackupEnhancePolicyRequest.

        实例ID

        :return: The instance_id of this ListUpdateBackupEnhancePolicyRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this ListUpdateBackupEnhancePolicyRequest.

        实例ID

        :param instance_id: The instance_id of this ListUpdateBackupEnhancePolicyRequest.
        :type instance_id: str
        """
        self._instance_id = instance_id

    @property
    def time_zone(self):
        """Gets the time_zone of this ListUpdateBackupEnhancePolicyRequest.

        用户当前时区，例：plus08

        :return: The time_zone of this ListUpdateBackupEnhancePolicyRequest.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this ListUpdateBackupEnhancePolicyRequest.

        用户当前时区，例：plus08

        :param time_zone: The time_zone of this ListUpdateBackupEnhancePolicyRequest.
        :type time_zone: str
        """
        self._time_zone = time_zone

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListUpdateBackupEnhancePolicyRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrds-3.1.157-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/list_update_backup_enhance_policy_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListUpdateBackupEnhancePolicyRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'instance_id': 'str',
        'time_zone': 'str'
    }

    attribute_map = {
        'instance_id': 'instance_id',
        'time_zone': 'time_zone'
    }

    def __init__(self, instance_id=None, time_zone=None):
        r"""ListUpdateBackupEnhancePolicyRequest

        The model defined in huaweicloud sdk

        :param instance_id: 实例ID
        :type instance_id: str
        :param time_zone: 用户当前时区，例：plus08
        :type time_zone: str
        """
        
        

        self._instance_id = None
        self._time_zone = None
        self.discriminator = None

        self.instance_id = instance_id
        if time_zone is not None:
            self.time_zone = time_zone

    @property
    def instance_id(self):
        r"""Gets the instance_id of this ListUpdateBackupEnhancePolicyRequest.

        实例ID

        :return: The instance_id of this ListUpdateBackupEnhancePolicyRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        r"""Sets the instance_id of this ListUpdateBackupEnhancePolicyRequest.

        实例ID

        :param instance_id: The instance_id of this ListUpdateBackupEnhancePolicyRequest.
        :type instance_id: str
        """
        self._instance_id = instance_id

    @property
    def time_zone(self):
        r"""Gets the time_zone of this ListUpdateBackupEnhancePolicyRequest.

        用户当前时区，例：plus08

        :return: The time_zone of this ListUpdateBackupEnhancePolicyRequest.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        r"""Sets the time_zone of this ListUpdateBackupEnhancePolicyRequest.

        用户当前时区，例：plus08

        :param time_zone: The time_zone of this ListUpdateBackupEnhancePolicyRequest.
        :type time_zone: str
        """
        self._time_zone = time_zone

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListUpdateBackupEnhancePolicyRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
